"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _path = _interopRequireDefault(require("path"));

var _readPkg = _interopRequireDefault(require("read-pkg"));

var _writePkg = _interopRequireDefault(require("write-pkg"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function readPackageJson(filePath) {
  try {
    return _readPkg.default.sync(filePath, {
      normalize: false
    });
  } catch (e) {
    throw new Error('Input package.json file does not exist or has bad format, check "inputPackageJson" option');
  }
}

function writePackageJson(folder, contents) {
  try {
    return _writePkg.default.sync(folder, contents);
  } catch (e) {
    throw new Error('Unable to save generated package.json file, check "outputFolder" option');
  }
}

function _default(options = {}) {
  const inputPackageJson = readPackageJson(options.inputPackageJson);
  const baseContents = options.baseContents || {};
  const additionalDependencies = options.additionalDependencies || [];
  let dependencies = [];
  return {
    name: 'generate-package-json',
    ongenerate: ({
      bundle
    }) => {
      dependencies = [...bundle.imports, ...additionalDependencies].sort();
    },
    onwrite: details => {
      const outputPackageJson = options.outputFolder || _path.default.dirname(details.file);

      const inputPackageJsonDependencies = inputPackageJson.dependencies;
      const generatedDependencies = {};
      dependencies.forEach(dependency => {
        if (inputPackageJsonDependencies && inputPackageJsonDependencies[dependency]) {
          generatedDependencies[dependency] = inputPackageJsonDependencies[dependency];
        }
      });
      const generatedJson = Object.assign({}, baseContents, Object.keys(generatedDependencies).length && {
        dependencies: generatedDependencies
      });
      writePackageJson(outputPackageJson, generatedJson);
    }
  };
}